==> zio-aws-apigatewayv2_3-5.17.116.1-sources.jar: zio/aws/apigatewayv2/model/ResetAuthorizersCacheRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class ResetAuthorizersCacheRequest(
    apiId: __string,
    stageName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.ResetAuthorizersCacheRequest = {
    import ResetAuthorizersCacheRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.ResetAuthorizersCacheRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .stageName(__string.unwrap(stageName): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.ResetAuthorizersCacheRequest.ReadOnly =
    zio.aws.apigatewayv2.model.ResetAuthorizersCacheRequest
      .wrap(buildAwsValue())
}
object ResetAuthorizersCacheRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.ResetAuthorizersCacheRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.ResetAuthorizersCacheRequest =
      zio.aws.apigatewayv2.model.ResetAuthorizersCacheRequest(apiId, stageName)
    def apiId: __string
    def stageName: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getStageName: ZIO[Any, Nothing, __string] = ZIO.succeed(stageName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.ResetAuthorizersCacheRequest
  ) extends zio.aws.apigatewayv2.model.ResetAuthorizersCacheRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val stageName: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.stageName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.ResetAuthorizersCacheRequest
  ): zio.aws.apigatewayv2.model.ResetAuthorizersCacheRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigatewayv2_3-5.17.295.16-sources.jar: zio/aws/apigatewayv2/model/ResetAuthorizersCacheRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class ResetAuthorizersCacheRequest(
    apiId: __string,
    stageName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.ResetAuthorizersCacheRequest = {
    import ResetAuthorizersCacheRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.ResetAuthorizersCacheRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .stageName(stageName: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.ResetAuthorizersCacheRequest.ReadOnly =
    zio.aws.apigatewayv2.model.ResetAuthorizersCacheRequest
      .wrap(buildAwsValue())
}
object ResetAuthorizersCacheRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.ResetAuthorizersCacheRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.ResetAuthorizersCacheRequest =
      zio.aws.apigatewayv2.model.ResetAuthorizersCacheRequest(apiId, stageName)
    def apiId: __string
    def stageName: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getStageName: ZIO[Any, Nothing, __string] = ZIO.succeed(stageName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.ResetAuthorizersCacheRequest
  ) extends zio.aws.apigatewayv2.model.ResetAuthorizersCacheRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val stageName: __string = impl.stageName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.ResetAuthorizersCacheRequest
  ): zio.aws.apigatewayv2.model.ResetAuthorizersCacheRequest.ReadOnly =
    new Wrapper(impl)
}
